var Request = require('./request')
  , util = require('util')
  , path = require('path')
  , fs = require('fs')
  , utils = require('./utils');

function Email(options){
  Request.call(this, options);
}
util.inherits(Email, Request);
module.exports = Email;

Email.prototype.send = function(callback) {
  this._send('mail', 'send', callback);
};

['to', 'toname', 'bcc'].forEach(function(option){
  Email.prototype[option] = function(val){
    if(this.options[option] && !Array.isArray(this.options[option]))
      this.options[option] = [this.options[option]];
    if(!this.options[option]) this.options[option] = val;
    else this.options[option].push(val);
    return this;
  }
});

['from', 'fromname', 'replyto', 
 'subject', 'text', 'html'].forEach(function(option){
  Email.prototype[option] = function(val){
    this.options[option] = val;
    return this;
  }
});

Email.prototype.file = function(file, encoding){
  var self = this;
  
  if(file instanceof Buffer){
    this.options['files['+file+']'] = file.toString(encoding || 'utf-8');
    return this;
  }
  self._promises++;
  fs.readFile(file, function(err, data){
    if(!err){
      self.options['files['+path.basename(file)+']'] = data.toString(encoding || 'utf-8'); 
    }
    self._complete(err);
  });
  
  return this;
};

Email.prototype.phone = function(phone){
  this.to(phone+'@phone');
  return this;
};

Email.prototype.footer = function(){ // todo
  this._addFilterSetting('footer', 'enable', 1);
  this._addFilterSetting('footer', 'text/html', '<h1>footer!</h1>');
  this._addFilterSetting('footer', 'text/plain', 'footer!');
  return this;
}

Email.prototype.clicktrack = function(track){
  this._addFilterSetting('clicktrack', 'enable', (track === false) ? 0 : 1);
  return this;
}

Email.prototype.opentrack = function(track){
  this._addFilterSetting('opentrack', 'enable', (track === false) ? 0 : 1);
  return this;
}

Email.prototype.bypass = function(bypass){
  this._addFilterSetting('bypass_list_management', 'enable', (bypass === false) ? 0 : 1);
  return this;
}

Email.prototype.notification = function(options){
  for(prop in options){
    if(prop == 'url') this._addFilterSetting('eventnotify', prop, options[prop]);
    else this._addFilterSetting('eventnotify', prop, (options[prop] === false) ? 0 : 1 );
  }
  return this;
};

Email.prototype.template = function(html){
  this._addFilterSetting('template', 'text/html', html);
  return this;
}

Email.prototype.subscription = function(options){
  for(prop in options){
    if(prop == 'enable') this._addFilterSetting('subscriptiontrack', prop, (options[prop] === false) ? 0 : 1 );
    else this._addFilterSetting('subscriptiontrack', prop, options[prop]);
  }
  return this;  
}

Email.prototype.spamcheck = function(options){
  for(prop in options){
    if(prop == 'enable') this._addFilterSetting('spamcheck', prop, (options[prop] === false) ? 0 : 1);
    else this._addFilterSetting('spamcheck', prop, options[prop] );
  }
  return this;  
}

Email.prototype.ganalytics = function(source, medium, campaign, term, content){
  
}

Email.prototype.sub = function(key, val){
  if(!isArray(this.options.smtpapi.sub)) this.options.smtpapi.sub = {};
  if(!isArray(this.options.smtpapi.sub[key])) this.options.smtpapi.sub[key] = [];
  this.options.smtpapi.sub[key].push(val);
  return this;
}
