var https = require('https')
  , qs = require('querystring').stringify
  , parse = require('url').parse
  , fs = require('fs')
  , utils = require('./utils');

function SendGridRequest(options){
  this._uri = 'https://sendgrid.com/api/';
  this._format = 'json';
  this._promises = 0;
  this._errors = [];
  
  this.options = options || {};
};

SendGridRequest.prototype.header = function(key, val){
  if(!this.options.headers) this.options.headers = {};
  this.options.headers[key] = val;
  return this;
};

SendGridRequest.prototype.settings = function(options){
  this.options = utils.merge(this.options, options);
  return this;
}

SendGridRequest.prototype.custom = function(options){
  if(typeof options != 'object') return;
  if (!this.options.smtpapi) this.options.smtpapi = {};
  this.options.smtpapi.unique_args = utils.merge(this.options.smtpapi.unique_args || {}, options);
  return this;
};

SendGridRequest.prototype.category = function(category){
  if (!this.options.smtpapi) this.options.smtpapi = {};
  this.options.smtpapi.category = category;
  return this;
};

SendGridRequest.prototype._addFilterSetting = function(filter, setting, val){
  if(!this.options.smtpapi) this.options.smtpapi = {};
  if(!this.options.smtpapi.filters) this.options.smtpapi.filters = {};
  if(!this.options.smtpapi.filters[filter]) this.options.smtpapi.filters[filter] = {};
  if(!this.options.smtpapi.filters[filter].settings) this.options.smtpapi.filters[filter].settings = {};
  this.options.smtpapi.filters[filter].settings[setting] = val;
};

SendGridRequest.prototype._complete = function(err){
  if(err) this._errors.push(err);
  this._promises--;
  if(this._deferred && this._promises === 0) this._send(this._deferred[0], this._deferred[1], this._deferred[2]);
};

SendGridRequest.prototype._send = function(module, action, callback){
  if (this._promises) return this._deferred = arguments;
  
  var url = this._uri + module + (action ? '.' + action : '') + '.' + this._format
    , parsedUrl = parse(url, true)
    , headers = {}
    , responseData = '';
  
  if(this.options.headers) this.options.headers = JSON.stringify(this.options.headers);
  if(this.options.smtpapi) this.options['x-smtpapi'] = JSON.stringify(this.options.smtpapi);
  
  var postData = qs(this.options);
  
  headers['Content-Type'] = 'application/x-www-form-urlencoded';
  headers['Content-Length'] = postData.length;
  
  //console.log(url, this.options, postData);
  
  var req = https.request({
    host: parsedUrl.host
  , port: 443
  , path: parsedUrl.pathname
  , method: 'POST'
  , headers: headers
  }, function(res){
    res.setEncoding('utf8');
    res.on('data', function(chunk) { responseData+= chunk; });
    res.on('end', function() {
      if (res.statusCode != 200) return callback({statusCode: res.statusCode, data: responseData});
      else{
        if(res.headers['content-length'] == '0') return callback(null,[]);
        var json = JSON.parse(responseData);
        if(json.message == 'error') return callback(json.errors);
        else return callback(null, json);
      }
    });
    res.on('error', function(err){ return callback(err); })
  });
  req.on('error', function(err){ return callback(err); });

  req.write(postData);
  req.end();  
  
};

module.exports = SendGridRequest;
