var Request = require('./request')
  , Email = require('./email')
  , utils = require('./utils');
  
var SendGrid = module.exports = function(config) {
  this.config = config;
}

SendGrid.prototype = {

  /*
    Email
  */  
  compose: function(options) {
    return new Email(this.config).settings(options);
  },
  email: function(options, callback) {
    var email = this.compose(options);
    if (typeof callback == 'function') {
      email.send(callback);
    } else {
      return email;
    }
  },
  
  /*
    Profile
  */
  getProfile: function(callback) {
    var req = new Request(this.config);
    req._send('profile', 'get', callback);
  },
  setProfile: function(options, callback) {
    var req = new Request(this.config).settings(options);
    req._send('profile', 'set', callback);
  },
  setUsername: function(username, callback) {
    var req = new Request(this.config).settings({ username: username });
    req._send('profile', 'setUsername', callback);
  },
  setPassword: function(password, callback) {
    var req = new Request(this.config).settings({ password: password, confirm_password: password });
    req._send('password', 'set', callback);
  },
  setEmail: function(email, callback) {
    var req = new Request(this.config).settings({ email: email });
    req._send('profile', 'setEmail', callback);
  },
  
  /*
    Bounces
  */
  getBounces: function(date, callback) {
    this._retrieve('bounces', date, callback);
  },
  deleteBounces: function(email, callback) {
    this._delete('bounces', email, callback);
  },
  
  /*
    Subscription management
  */
  unsubscribe: function(email, callback) {
    var req = new Request(this.config).settings({ email: email });
    req._send('unsubscribes', 'add', callback);
  },
  getUnsubscribes: function(date, callback) {
    this._retrieve('unsubscribes', date, callback);
  },
  deleteUnsubscribes: function(email, callback) {
    this._delete('unsubscribes', email, callback);
  },
  
  /*
    Newsletter management
  */
  addRecipientToList: function(list, name, email, callback) {
    var req = new Request(this.config);
    req.settings({
        list: list
      , data: JSON.stringify({ name: name, email: email })
    });
    req._send('newsletter/lists/email/add', '', callback)
  },
  removeRecipientFromList: function(list, email, callback) {
    var req = new Request(this.config);
    req.settings({
        list: list
      , email: email
    });
    req._send('newsletter/lists/email', 'delete', callback)
  },
  
  /*
    Spam reports
  */
  getSpamReports: function(date, callback) {
    this._retrieve('spamreports', date, callback);
  },
  deleteSpamReports: function(email, callback) {
    this._delete('spamreports', email, callback);
  },
  
  /*
    Invalid emails
  */
  getInvalidEmails: function(date, callback) {
    this._retrieve('invalidemails', date, callback);
  },
  deleteInvalidEmails: function(email, callback) {
    this._delete('invalidemails', email, callback);
  },
  
  
  _retrieve: function(module, date, callback) {
    var req = new Request(this.config);
    
    if (typeof callback == 'undefined') {
      callback = date;
      req.settings({ date: 1 });
    } else if (date === true) {
      req.settings({ date: 1 });
    }
    
    req._send(module, 'get', callback);
  },
  _delete: function(module, email, callback) {
    var req = new Request(this.config).settings({ email: email });
    req._send(module, 'delete', callback);
  }
  
};
