var assert = require('assert')
  , config = require('./config')
  , sendgrid = require('../lib');
  
var sg = sendgrid.connect(config);
  
module.exports = {
  
  'send basic email with object syntax': function() {
    sg.email({
        to: 'conner@storify.com'
      , from: 'test@storify.com'
      , text: 'testing email with object syntax'
      , subject: 'testing email with object syntax'
    }, function(e, r) {
      assert.isNull(e);
      assert.eql(r, { message: 'success' });
    });
  },
  
  'send basic email with alternate syntax': function() {
    var email = sg.compose({
        to: 'conner@storify.com'
      , from: 'test@storify.com'
      , text: 'testing email with alternate syntax'
      , subject: 'testing email with alternate syntax'
    });
    
    email.send(function(e, r) {
      assert.isNull(e);
      assert.eql(r, { message: 'success' });
    });
  },
  
  'send basic email with chained syntax': function() {
    sg.compose()
      .to('conner@storify.com')
      .from('test@storify.com')
      .text('testing email with chained syntax')
      .subject('testing email with chained syntax')
      .send(function(e, r) {
        assert.isNull(e);
        assert.eql(r, { message: 'success' });
      });
  },
  
  'send basic email with multiple recipients': function() {
    sg.email  ({
        to: ['conner@storify.com', 'cpetzold@storify.com', 'conner+test@storify.com']
      , from: 'test@storify.com'
      , text: 'hello world'
      , subject: 'testing email with multiple recipients'
    }, function(e, r) {
      assert.isNull(e);
      assert.eql(r, { message: 'success' });
    });
  },
  
  'send advanced email': function() {
    sg.compose()
      .phone('970-402-0413')
      .to('conner@storify.ocm')
      .to('cpetzold@storify.com')
      .bcc('cpetzold@gmail.com')
      .from('test@storify.com')
      .fromname('node-sendgrid')
      .replyto('noreply@storify.com')
      .file('./test/email.test.js')
      .category('test')
      .subject('testing advanced email')
      .html('<h3>This is a test email!</h3>')
      // .template(template)
      .subscription({
        'enable': true
      , 'text/html': "If you would like to unsubscribe and stop receiving these emails <% Click Here %>."
      , 'text/plain': "If you would like to unsubscribe and stop receiving these emails <% %>."
      , url: 'http://yoursite.com/unsubscribe'
      })
      .opentrack(false)
      .clicktrack(false)
      .bypass()
      // .ganalytics(source, medium, campaign, term, content)
      .footer()
      .custom({'name': 'Dummy Name', 'phone': '555-555-5555'})
      .send(function(e, r){
        assert.isNull(e);
        assert.eql(r, { message: 'success' });
      });
  }
  
};